#
# spec file for package ghostwriter
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.3.0
%define qt6_version 6.6.0

%bcond_without released
Name:           ghostwriter
Version:        24.08.3
Release:        1.1
Summary:        A distraction-free Markdown editor
License:        GPL-3.0-or-later
URL:            https://ghostwriter.kde.org
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF6ConfigWidgets) >= %{kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6DocTools) >= %{kf6_version}
BuildRequires:  cmake(KF6Sonnet) >= %{kf6_version}
BuildRequires:  cmake(KF6WidgetsAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6XmlGui) >= %{kf6_version}
BuildRequires:  cmake(Qt6Concurrent) >= %{qt6_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6Core5Compat) >= %{qt6_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6LinguistTools) >= %{qt6_version}
BuildRequires:  cmake(Qt6Svg) >= %{qt6_version}
BuildRequires:  cmake(Qt6WebChannel) >= %{qt6_version}
BuildRequires:  cmake(Qt6WebEngineWidgets) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
BuildRequires:  pkgconfig(hunspell)
Recommends:     multimarkdown
# It can only build on the same platforms as Qt Webengine
ExclusiveArch:  x86_64 %{x86_64} aarch64 riscv64

%description
ghostwriter is a text editor for Markdown, which is a plain text markup format.
For more information about Markdown, please visit John Gruber’s website at
http://www.daringfireball.net.
Ghostwriter provides a relaxing, distraction-free writing environment.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf6 -DBUILD_WITH_QT6:BOOL=TRUE

%kf6_build

%install
%kf6_install

%find_lang %{name} --with-qt --with-man

%files
%license LICENSES/*
%doc README.md
%doc %lang(en) %{_kf6_mandir}/man1/ghostwriter.1%{?ext_man}
%{_kf6_applicationsdir}/org.kde.ghostwriter.desktop
%{_kf6_appstreamdir}/org.kde.ghostwriter.metainfo.xml
%{_kf6_bindir}/ghostwriter
%{_kf6_iconsdir}/hicolor/*/apps/ghostwriter.*

%files lang -f %{name}.lang

%changelog
* Tue Nov  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.3/
- No code change since 24.08.2
* Tue Oct  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.2/
- No code change since 24.08.1
* Tue Sep 10 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.1/
- No code change since 24.08.0
* Mon Aug 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.0/
- Changes since 24.05.2:
  * Port to ecm_add_test to actually run the tetsts
  * Drop unused qt5compat dependency
  * snapcraft: Set QT_LIBRARY_DATA and fix formatting.
  * Fix actions translations not working (kde#490493)
  * snapcraft: Initial qt6 import.
  * Fix Messages.sh: remove spurious non-printable characters
  * Remove Qt5 CI
  * Remove creation of ghostwriterui.rc from CMakeLists.txt
  * Fix syntax highlighting with unicode characters (kde#487636)
  * Port to Qt6 and Remove QtFontAwesome (boo#1222875, kde#485691)
  * Squashed commit of the following:
* Tue Jul  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.2/
- No code change since 24.05.1
* Wed Jun 12 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.1/
- No code change since 24.05.0
* Sun May 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.0/
- No code change since 24.04.80
* Fri May  3 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.04.80
  * New feature release
- Changes since 24.02.2:
  * Fix IME position when window is wider than editor width. (kde#478960)
* Tue Apr  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.2/
- No code change since 24.02.1
* Tue Mar 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.1/
- Changes since 24.02.0:
  * Fix IME position when window is wider than editor width. (kde#478960)
* Fri Feb 23 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.0
  * New feature release
- No code change since 24.01.95
* Fri Feb  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.01.95
  * https://kde.org/announcements/megarelease/6/rc2/
* Fri Dec 15 2023 Christophe Marin <christophe@krop.fr>
- Require extra-cmake-modules at build time
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- No code change since 23.08.3
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- Changes since 23.08.2:
  * snapcraft: initial import snapcraft files.
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- No code change since 23.08.1
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- No code change since 23.08.0
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- No code change since 23.07.90
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- No code change since 23.07.80
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- Changes since 23.04.3:
  * Include <cstdint> where needed
  * Fix build
  * Fix tr() extraction warning
  * Remove flatpak CI
  * Added configurable backup location for .backup files (kde#470425)
  * markdowneditor: Add support for code block
  * Remove comment from json file
  * Allow building against KF6
  * Add packages in requirement list for debian/ubuntu to build ghostwriter
  * Added checkbox to not open exported files on export if unselected.
  * Apply i18n to percentage value
  * kde neon ci tooloing requires a new line at the end of CMakeLists.txt
  * Show unbreakable space  indicator
  * Tidy up for KF6 transition, and add clazy/clang format support.
  * Update changelong with new release version
  * Fixes for toggling inline markup format
  * Syntax highlighting and live spell check performance improvements
  * Fix crash when currentHtmlExporter is null
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- No code change since 23.04.2
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- No code change since 23.04.1
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- No code change since 23.04.0
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Sat Mar 18 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Sat Oct  8 2022 Olivier Belleux <o.g.m.belleux@gmail.com>
- Good news from Nate Graham "KDE Welcomes a new app to the fold:
  Ghostwriter is now a KDE app!". So I update my last update
  https://KDE.github.io/ghostwriter --> https://ghostwriter.kde.org.
- Now I hope the website url is the good one !
* Thu Oct  6 2022 Olivier Belleux <o.g.m.belleux@gmail.com>
- New upstream release, update to version 2.1.6.
- list of fixes, see https://github.com/KDE/ghostwriter/releases/tag/2.1.6.
* Sun Jun 19 2022 Sebastien CHAVAUX <seb95.scou@gmail.com>
- New upstream release, update to version 2.1.4.
- list of fixes, see https://github.com/wereturtle/ghostwriter/releases/tag/2.1.4.
* Fri Jun  3 2022 Sebastien CHAVAUX <seb95.scou@gmail.com>
- New upstream release, update to version 2.1.3.
- list of fixes, see https://github.com/wereturtle/ghostwriter/releases/tag/2.1.3.
* Wed Mar 16 2022 Sebastien CHAVAUX <seb95.scou@gmail.com>
- New upstream release, update to version 2.1.2.
- list of fixes, see https://github.com/wereturtle/ghostwriter/releases/tag/2.1.2.
* Sun Dec 26 2021 Sebastien CHAVAUX <seb95.scou@gmail.com>
- New upstream release, update to version 2.1.1.
- list of fixes, see https://github.com/wereturtle/ghostwriter/releases/tag/2.1.1.
* Mon Nov 22 2021 Sebastien CHAVAUX <seb95.scou@gmail.com>
- Update to 2.1.0.
- list of fixes, see https://github.com/wereturtle/ghostwriter/releases/tag/2.1.0
* Thu Jul 15 2021 Cor Blom <cornelis@solcon.nl>
- Update to 2.0.2:
  * Unicode characters are properly displayed in the sidebar's
    Outline.
  * Chinese and other languages with unicode characters now display
    properly in the HTML preview.
* Mon May 31 2021 Martin Pluskal <mpluskal@suse.com>
- Fix source url
* Sun May 30 2021 Cor Blom <cornelis@solcon.nl>
- Update to 2.0.1:
  Fixed:
  * Issue #598: Unicode characters no longer shifts syntax
    highlighting.
  * Sidebar now properly hides itself after the `Ctrl+J` Outline
    command if it was
    previously hidden on initial launch.
  * New Norwegian translation added.
  * Spanish and Italian translations updated.
- Update to 2.0.0:
  Added:
  * cmark-gfm now replaces Sundown as the default Markdown processor
    for live previews an export.
  * Syntax highlighting now utilizes cmark-gfm for better accuracy,
    especially with nested blocks.
  * HUDs have been replaced with a side bar.
  * Theming has been revamped to include more color options, but to
    exclude background images.
  * CSS for HTML Preview now adaptively changes colors based on the
    current theme.
  * Fonts can be customized for the HTML preview in the Preview
    Options dialog.
  * Themes are now composed of two color schemes: a light mode and a
    dark mode.
  * A new dark mode button in the status bar allows users to switch
    to the current theme's dark mode.
  * Find and replace dialog has been revamped into a panel at the
    bottom of the application.
  * Find and replace now supports highlighting all matches.
  * Export dialog now uses native file selector dialog.
  * Any two spaces at the end of a line are marked with dots by
    default.
  * Selected text now reveals tabs and spaces.
  * Source code has been refactored to follow KDE Frameworks and Qt
    coding style guides.
  * ghostwriter now uses React to update only what changed in the
    live preview since the last keystroke, significantly reducing
    the live preview rendering time for large documents.
  Fixed:
  * Issue #281: Removal of HUD windows will facilitate Alt+Tab
    switching.
  * Issue #382, #539: IME selection window/IBUS candidate window
    should no longer be displaced.
  * Issue #401: Single column tables are now highlighted.
  * Issue #439: README file was updated to remove the installation
    of qt5-default on Debian-based systems.
  * Issue #480: Menu bar is now accessible on relaunching ghostwriter
    in full screen mode.
  * Issue #494: MathJax JavaScript syntax error that was being
    printed to the terminal and which prevented inline math from
    being displayed with the `$` sign has been fixed.
  * Issue #500: Preview Options dialog will now only open once.
  * Issue #507: Multilevel lists are highlighted correctly in the
    editor with the switch to cmark-gfm handling the syntax
    highlighting.
  * Issue #508: HUD windows have been replaced with a side bar for
    compatibility with Wayland.
  * Issue #517: README.md has been updated with correct instructions
    location for building on MacOS.
  * Issue #503: MathJax has now been included inside the application
    rather than fetching it externally.
  * Issue #532: Insert spaces for tabs now works on startup.
  * Issue #536: Added missing Markdown file extensions to file
    dialog filter when opening and saving files.
  Removed:
  * Discount support was removed due to its conflicting executable
    name with MultiMarkdown.
- Remove 0001-Fix-build-with-Qt-5.15.patch
* Thu Jun  4 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add patch to fix build with Qt 5.15:
  * 0001-Fix-build-with-Qt-5.15.patch
* Mon Feb 24 2020 Sebastien CHAVAUX <seb95passionlinux@opensuse.org>
- Update to version 1.8.1:
  * Issue #443: MathJax 3.0 is now built into the HTML preview. Note that this feature works best with Pandoc and requires an Internet connection. Other Markdown processors are not currently supported.
  * Issue #447: Cursor is no longer shown when editor is not in focus.
  * Issue #461: Fixed Cheat Sheet to have correct image example.
  * Issue #471: HUD window styling is fixed for Qt 5.13.
  * Issue #472: Fixed typing paused timers for session statistics and for hiding HUD windows.
  * Discount is not listed as an available Markdown processor if MultiMarkdown is installed.
  * New application translations are available for the following languages:
    + Arabic
    + Dutch
* Wed May  1 2019 Sebastien CHAVAUX <seb95passionlinux@opensuse.org>
- Update to version 1.8.0:
  * New Features: HTML preview has been ported from QtWebKit to QtWebEngine (Chromium).
  * Issue #206: ghostwriter now has right-to-left language support.
  * Issue #391: mathml option for pandoc is now used to render math equations for preview and export.
  * Issue #411: Fixed crash when adding a new theme with no theme selected.
  * Issue #412: Fixed export to PDF (wkhtmltopdf) failure with Pandoc.
  * Issue #430: Fixed issue extra spaces appearing between <br/> tags in the HTML preview.
  * Removed print support, since it has some odd bugs on some platforms, and most users would want to print their exported content anyway.
  * Removed graphics fade effect for the bottom of the editor, as it is a risky feature that has caused bugs in the past and does not work on HiDPI screens.
* Fri Dec 14 2018 Sebastien CHAVAUX <seb95.scou@gmail.com>
- Update to version 1.7.4:
  * Issue #178: Only use --quiet option for Pandoc version 2 or greater.
  * Fixed words-per-minute calculations to not be jumpy or overly high.
  * Fixed issue where creating a new theme resulted in inconsistent selection and display of themes in the Theme Selection dialog.
  * Fixed broken icon when running under Wayland.
  * Fixed screenshots in appdata.
  * Issue #385: Updated resource files license to CC BY-SA 4.0.
* Fri Aug 24 2018 seb95.scou@gmail.com
- Update to version 1.7.3:
  * Fixed segfault that occurred when changing the theme or interface style after opening the Preview Options dialog.
* Tue Jul 31 2018 mpluskal@suse.com
- Update to version 1.7.2:
  * Fixed issue where the --quiet option was mistakenly used with older Pandoc versions that did not support its use.
  * Worked around Qt 5.11 qinstall bug where running qmake and make would fail when installing the translation files
* Mon Jul 23 2018 seb95.scou@gmail.com
- Update to version 1.7.1
  * Fixed regression in full screen mode where menu bar was not showing on mouse-over.
  * Fixed regression where wrong theme was shown as selected on opening the Theme Selection dialog.
  * Fixed issue #366 where warnings from Pandoc that were resulting in error dialogs on successful export.
  * Fixed issue #292 where saving a document under Windows resulted in end-of-line characters being written as \n instead of \r\n.
  * Fixed issue #360 where a graphical glitch under MacOS disabled the Theme Selection dialog's remove theme button.
* Wed Jul 18 2018 seb95.scou@gmail.com
- Update to version 1.7.0
  * Added light and dark built-in themes based on the community Ulysses III theme Plainstraction.
  * @sbrl added a new Github Dark built-in stylesheet for use with the live preview.
  * Live preview has been optimized to show the preview for typed characters immediately on smaller documents.
  * Added ODT and EPUB 3 as export options for MultiMarkdown 6.
  * Theme selection dialog now displays a grid instead of a list.
  * The menu bar is now hidden again in full screen mode when the user presses Alt+Tab to switch to a different application.
  * Fixed issue #354 to disable hard line breaks for Pandoc's Github-flavored Markdown.
  * Worked around issue in Qt 5.11 where changing the theme causes the app to crash.
  * Worked around issue in Qt 5.10 where opening a new document with a document already loaded can cause the app to crash.
* Mon Apr 16 2018 seb95.scou@gmail.com
- Update to version 1.6.2
  * Issue #315: Worked around slow load of QPrinter constructor in
    Fedora 27 by lazy loading the printer settings only when needed
    for printing or print preview rather than during application
    startup.
  * Fixed line break tokenizing to not include paragraph breaks.
* Mon Apr  9 2018 seb95.scou@gmail.com
- New upstream release, update to version 1.6.1
  * Worked around an issue with Qt version 5.10 that causes the
  application to occasionally crash when reloading the currently
  opened document or when opening a new document due to the text
  cursor not being set to the beginning of the document before
  clearing the editor and loading the new document.
* Mon Apr  9 2018 mpluskal@suse.com
- Run spec-cleaner
- Drop not needed scriplets
* Sun Apr  8 2018 seb95.scou@gmail.com
- Update to version 1.6.0
  * HTML live preview is now in a split pane view rather than in a
  separate window.
  * New options were added to hide HUD windows while typing, in full
  screen mode, or in live preview mode.
  * A new button was added to the status bar and a new shortcut was
  added to the View menu in the menu bar to toggle hiding/showing the
  open HUDs.
  * Github's cmark-gfm can now be detected and used as a Markdown
  processor.
  * Block quotes and code blocks now have an inobtrusive background
  color to differentiate them.
  * Buttons have been added to the status for existing features.
  * HUD windows and scrollbars can be stylized to have square or
  rounded corners in the Settings, and are no longer theme dependent.
  * New "Typewriter" focus mode was added by @hirschenberger.
  * The style sheet and Markdown processor to use with the HTML live
  preview can now be selected in their own dialog box accessible both
  from the status bar at the bottom of the window and from the menu bar
  in the Settings menu.
  * The "Copy HTML" button has been moved to the "status bar" at the
  bottom of the main window.
  * The "Copy HTML" button / menu bar option can copy just the selected
  Markdown text as HTML (using the currently selected Markdown
  processor). It will still copy the entire Markdown text document and
  convert it to HTML in the system clipboard if no text is selected.
  * Themes now support options for emphasis color and block text color.
  Note that emphasis color will also affect the color of headings, and
  block text color will affect the color of block quotes and code blocks.
  * Issue #302: ghostwriter will now look for default Qt
  translations on the standard Qt translations path
  (for standard buttons/text). These default Qt translations
  have been included in the Windows installer translations
  folder and portable Windows Zip, and will be loaded automatically
  based on the currently selected application language.
  * Some tweaks have been made to the parsing/highlighting of
  emphasized text to handle nested emphasis cases better. As part
  of this effort, ghostwriter uses a Qt 5-specific regular
  expression class that is not available in Qt 4. As such,
  ghostwriter can no longer be built with Qt and must be built with
  Qt 5.
  * Issue #272: Fixed issue with Focus mode where inserting
  matching characters around a selection was causing the application
  to crash.
  * Issue #260: Added compatability with Pandoc version 2 and
  MultiMarkdown version 6.
  * Fixed issue where HTML preview scrolls to the top if the new
  HTML from a modified document matches the old HTML, even if the
  markup used in the source document did change.
  * Fixed issue where current word is not live spell checked if the
  user switches the text cursor to a different line.
  * Fixed issue where prompt to reload a file that has been modified
  externally was being displayed multiple times per file change. This
  seems to have been triggered by some editors like Sublime Text that
  perform multiple file saves for a single file modification.
  * Issue #228: Selected text can now be dragged and dropped to a
  different location within the editor.
  * Fixed issue where if setext heading markup line is selected and
  deleted with the cursor position beginning at the end of the previous
  line, the heading is not removed from the Outline HUD.
  * Fixed issue where Preview HTML menu item and button were not in
  sync to appear checked or unchecked.
  * ghostwriter now clears the Outline HUD when loading or reloading
  a document to prevent a crash in case bad data is in the HUD.
  * Fixed copy HTML issue to ensure Markdown text has proper formatting
  (i.e., greater than signs aren't converted to &gt;).
  * ghostwriter will now search in the mozilla-dicts installation
  location for dictionaries on OpenBSD.
* Fri Nov  3 2017 mpluskal@suse.com
- Update suggested packages and recommend virtual package markdown
* Sun May 28 2017 mpluskal@suse.com
- Update suggested packages
* Sat May 27 2017 luke.nukem.jones@gmail.com
- Update to version 1.5.0
  * HUD windows can now be closed using the Esc key when they have
    focus.
  * A new option has been added to highlight double spaces at the
    end of a line.
  * Github-style task lists can now be made using the * and +
    bullet point characters, in addition to the - character.
  * Support for ConTeXt and wkhtmltopdf when exporting to PDF with
    Pandoc has been added.
  * Auto-matching characters for selected text now respects the
    existing preferences for the matching done while typing without
    text selected.
  * Typing a single quote (') will no longer result in a second
    quote being automatically inserted after the cursor if the
    cursor is positioned in the middle of a word.
  * Most settings have been moved into a new Preferences dialog to
    accommodate the ever increasing number of application options.
  * Font size can now be increased by pressing Ctrl+=or decreased
    by pressing Ctrl+-. It can also be changed by using Ctrl and
    the mouse wheel.
  * When exporting to other file formats, the output file will be
    opened after export with its default application.
  * E-books created using Pandoc will now also be generated with a
    table of contents.
  * When passing in a file path via the command line, a new file
    will be created with that path if it does not already exist.
  * When typing a * character, ghostwriter would auto-insert a
    second '*' character in anticipation of emphasized text. The
    auto-inserted second * will now be removed if a space is typed
    to accommodate a bullet list instead.
  * Rudimentary support for HiDPI has been added. See notes below.
  * Various performance enhancements and tweaks have been made
    under the hood.
  * Hyphenated words are now considered one word for spell checking
  * ghostwriter can now be built from its source tarball without
    needing git to be installed.
  * Linux desktop file now specifies that ghostwriter can open only
    one file from the command line rather than multiple files.
  * Ctrl+M now opens the HTML Preview instead of Ctrl+W. This is to
    avoid a conflict with closing windows in Linux.
  * Copy and paste no longer makes the word count jump.
  * Sundry minor fixes have been added.
* Sun Feb 19 2017 mpluskal@suse.com
- Split lang subpackage and generate/install translations
- Suggest MultiMarkdown-5 as well
* Thu Sep  8 2016 luke.nukem.jones@gmail.com
- Update to version 1.4.2:
  * Issue #113: Full screen clock now displays time based on
    locale.
  * Issue #119: Null characters, which had been breaking the HTML
    preview, are no longer inserted when typing over selecting text.
  * Issue #121: Code fences are now correctly highlighted when they
    contain blank lines.
  * Issue #123: Statistics HUDs now have proper padding when
    alternating row colors is enabled.
  * Issue #125: The translations folder has been moved up one
    folder for the portable distribution of ghostwriter.
  * Sundry minor fixes have been added.
* Mon Aug 15 2016 luke.nukem.jones@gmail.com
- Update to version 1.4.1:
  * Pressing backspace at the end of a line no longer deletes
    adjacent line breaks.
  * Renaming a theme no longer removes its background image.
  * Main window is now rendered correctly when transitioning
    between full screen mode and maximized. Main window also
    remembers its normal size upon being restored from maximized
    after having been in full screen mode previously.
* Wed Jul 27 2016 mpluskal@suse.com
- Update to version 1.4.0:
  * The time of day optionally displays in full screen mode.
  * The recent file history size has been increased to 10.
  * The menu bar will optionally auto-hide in full screen mode when
    the mouse is not hovering over it.
  * All new Hemingway mode button will disable backspace and
    delete keys.
  * Two new HUDs display statistical information on the current
    writing session and document.
  * Auto-matched characters can be customized.
  * Pandoc PDF export now has better defaults for margins and
    hyperlinks.
  * Shortcut keys using Alt now use Ctrl to avoid conflicts with
    OS shortcut keys and to better accommodate non-USA keyboards.
  * High DPI scaling has been enabled for Qt 5.6 and above.
  * Dragging and dropping an image into the editor will now insert
    the image link at the mouse location.
  * Classic Light and Classic Dark themes have new color palettes.
  * Various aesthetics have been added to the main window.
  * New application translations are available for the following
    languages:
    + German
    + Italian
    + Japanese
    + Portuguese (Brazil)
    + Russian
  * Sundry other fixes have been added.
* Thu May  5 2016 jengelh@inai.de
- Trim description to relevant parts.
* Sat Apr 30 2016 mpluskal@suse.com
- Initial package for version 1.3.1
